pub struct EndpointGetInfoResponse {
pub info: EndpointInfo,
}Fields
info: EndpointInfoTrait Implementations
Sourceimpl Clone for EndpointGetInfoResponse
impl Clone for EndpointGetInfoResponse
Sourcefn clone(&self) -> EndpointGetInfoResponse
fn clone(&self) -> EndpointGetInfoResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EndpointGetInfoResponse
impl Debug for EndpointGetInfoResponse
Sourceimpl<D: ResourceDialect> Decode<EndpointGetInfoResponse, D> for EndpointGetInfoResponse
impl<D: ResourceDialect> Decode<EndpointGetInfoResponse, D> for EndpointGetInfoResponse
Sourceimpl<D: ResourceDialect> Encode<EndpointGetInfoResponse, D> for &EndpointGetInfoResponse
impl<D: ResourceDialect> Encode<EndpointGetInfoResponse, D> for &EndpointGetInfoResponse
Sourceimpl<D: ResourceDialect, T0: Encode<EndpointInfo, D>> Encode<EndpointGetInfoResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<EndpointInfo, D>> Encode<EndpointGetInfoResponse, D> for (T0,)
Sourceimpl PartialEq for EndpointGetInfoResponse
impl PartialEq for EndpointGetInfoResponse
Sourcefn eq(&self, other: &EndpointGetInfoResponse) -> bool
fn eq(&self, other: &EndpointGetInfoResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Persistable for EndpointGetInfoResponse
impl StructuralPartialEq for EndpointGetInfoResponse
Sourceimpl TypeMarker for EndpointGetInfoResponse
impl TypeMarker for EndpointGetInfoResponse
Sourcetype Owned = EndpointGetInfoResponse
type Owned = EndpointGetInfoResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for EndpointGetInfoResponse
impl ValueTypeMarker for EndpointGetInfoResponse
Sourcetype Borrowed<'a> = &'a EndpointGetInfoResponse
type Borrowed<'a> = &'a EndpointGetInfoResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for EndpointGetInfoResponse
impl RefUnwindSafe for EndpointGetInfoResponse
impl Send for EndpointGetInfoResponse
impl Sync for EndpointGetInfoResponse
impl Unpin for EndpointGetInfoResponse
impl UnsafeUnpin for EndpointGetInfoResponse
impl UnwindSafe for EndpointGetInfoResponse